pub fn handler_to_method_router(
method: &str,
handler_box: HandlerBox,
) -> MethodRouterExpand description
Build an axum MethodRouter for a single registered route. Used by the
runtime to construct the live router after each reload.
pub fn handler_to_method_router(
method: &str,
handler_box: HandlerBox,
) -> MethodRouterBuild an axum MethodRouter for a single registered route. Used by the
runtime to construct the live router after each reload.